Utilities module
-----------------

.. currentmodule:: viqa.load_utils

.. autosummary::
   :toctree: generated

    load_data
    load_mhd
    load_raw
    load_nifti
    normalize_data

.. currentmodule:: viqa.utils

.. autosummary::
   :toctree: generated

    correlate_convolve_abs
    gabor_convolve
    export_csv